@@ -36,8 +36,8 @@ main = do
                                return (cfg, Just file, opts)
         _ -> do cfg <- readPersonalConfig (defaultConfigLocation False)
                 return (cfg,Nothing,options)
-  let defaultComp = usualCompiler cfg
-      opts = options ++ extraHiOptions defaultComp
+  defaultComp <- unDyn (usualCompiler cfg)
+  let opts = options ++ extraHiOptions defaultComp
   putStrLn banner
   putStrLn (replicate 43 ' '++
             "... Using compiler "++compilerPath defaultComp++" ...\n")
@@ -229,13 +229,14 @@ commands ws state = let target = tail ws in do
           putStrLn ("Current compiler: "++compilerPath (compiler state)
                     ++" ("++compilerVersion (compiler state)++")")
           putStr   "Compilers available:\n     "
+          kcs <- (mapM unDyn . knownComps . config) state
           putStrLn ((concat . intersperse ("\n     ")
                     . reverse . sort
                     . map (\cc->compilerPath cc++"\t("++compilerVersion cc++")")
-                    . knownComps . config) state)
+                    ) kcs)
        else if compilerKnown (head target) (config state) then do
-               let newcomp = matchCompiler (head target) (config state)
-                   newopts = ((options state)
+               newcomp <- unDyn (matchCompiler (head target) (config state))
+               let newopts = ((options state)
                                        \\ extraHiOptions (compiler state))
                                        ++ extraHiOptions newcomp
                makeclean ".o" (modules state)
@@ -342,11 +343,6 @@ makeclean ext modules = mapM_ (clean ext) modules
 --  if prefix `isPrefixOf` opt then Just (drop (length prefix) opt) else Nothing
 
 
-#if defined(__HBC__) && !defined(__HASKELL98__)
-banner = "hi - hmake interactive                (Version: "++hmakeVersion++")"
-help   = "hi - help command does not work in hbc < 0.9999.5"
-
-#else
 banner = "\ 
 \__   __                 __             _____________________________________\n\ 
 \||   ||  ______    ___  || _  ____     hmake interactive (hi):\n\ 
@@ -382,4 +378,3 @@ help = "\
 \  :!command            shell escape\n\ 
 \  :version             show hmake version\n\ 
 \  :?                   display this list of commands"
-#endif
